//
//   @file    ascache.cxx         
//   
//
//   @author M.Sutton
// 
//   Copyright (C) 2016 M.Sutton (sutt@cern.ch)    
//
//   $Id: ascache.cxx, v0.0   Tue  8 Nov 2016 11:16:30 CET sutt $



#include "ascache.h" 

#include <cmath>
#include <iostream>

#include "nnlo_common.h"


extern "C" double alphaspdf_( const double& Q );

double leading_order_factor( int order, const double alphas ) {
  if ( order==0 ) return 0;
  double factor = 1;
  for ( ; order-- ;  ) factor *= 2*M_PI/alphas; 
  //  std::cout << "leading order: factor: " << factor << "\talphas: " << alphas << std::endl;
  return factor;
}



double ascache( const double Q2, const int order ) { 

  static double alphas_ = 0;
  static double Q2_     = 0;

  static int      order_    = -1;
  static double   factor[4] = { 1, 1, 1, 1 };

  static int leading = inppar_.njets;

  if ( Q2!=Q2_ ) { 
    alphas_ = alphaspdf_( std::sqrt(Q2) ); 
    order_  = -1;
    Q2_     = Q2;  
    //    std::cout << "ascache() recalculate alphas " << alphas_ << std::endl;
  }

  if ( order>order_ ) {
    if ( order_==-1 ) factor[0] = leading_order_factor( leading, alphas_ );
    for ( int i=order_+1 ; i<=order ; i++ ) factor[i+1] = factor[i]*2*M_PI/alphas_;
    order_ = order;
    //    std::cout << "ascache() recalculate terms: order: " << order << "\tfactor: " << factor[order] << std::endl;
  }
  
  return factor[order];
}


